#Author : Priyanka Singh <ps21priyanka@gmail.com>

import pandas as pd
import numpy as np
def altercase(dataframe,method):
    """This function is usually to convert the content of dataframe either in lower case or upper case
    
    Parameters:
    1. dataframe : dataframe name where you want to change all its content as either lower or upper case
    2. method(str) : It has two options thats is either "lower" or "upper"

    How to call function(demo) : 
    1. caps_correction(df,"upper"): df -> name of your dataframe
                                    "upper" -> to convert every value string in upper case
    2. caps_correction(df,"lower"): df -> name of your dataframe
                                    "lower" -> to convert every value string in lower case
                                    
    Returns:
    Dataframe having its all values changed into either lower or upper case"""
    if method == "lower":
        return dataframe.apply(lambda x: x.astype(str).str.lower() if x.dtype.kind not in 'biufc' else x)
    elif method == "upper":
        return dataframe.apply(lambda x: x.astype(str).str.upper() if x.dtype.kind not in 'biufc' else x)
def altercase_subset(dataframe,columns,method):
    """This function is usually to convert the content of only selected columns either in lower case or upper case and returns dataframe having the content of mentioned columns either in lower or upper case
    
    Parameters:
    1. dataframe : dataframe name where you want to change all its content as either lower or upper case
    2. columns(list) : List of columns where you want the content to be either lower case or upper case
    3. method(str) : It has two options thats is either "lower" or "upper"

    How to call function(demo) : 
    1. caps_correction(df,['a','b'],"upper"): df -> name of your dataframe
                                              ['a','b'] -> columns of dataframe df
                                             "upper" -> to convert every value string in upper case
    2. caps_correction(df,['a','b'],"lower"): df -> name of your dataframe
                                              ['a','b'] -> columns of dataframe df
                                             "lower" -> to convert every value string in lower case
    Returns:
    Dataframe with the specified columns, having its value changesd into either lower or upper case"""
    if method=="lower":
        dataframe[columns] = dataframe[columns].apply(lambda x: x.astype(str).str.lower() if x.dtype.kind not in 'biufc' else x)
    elif method == "upper":
        dataframe[columns] = dataframe[columns].apply(lambda x: x.astype(str).str.upper() if x.dtype.kind not in 'biufc' else x)
    return dataframe
    


from distutils.core import setup

setup(

  name = 'samoy',         # How you named your package folder (MyLib)

  packages = ['samoy'],   # Chose the same as "name"

  version = '0.3',      # Start with a small number and increase it with every change you make

  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository

  description = 'samoy is a Python package for machine learning and data science, built on top of Pandas inbuilt libraries. This package will be useful for data pre-processing before starting off any machine learning or data science project as it will ease your entire process of data cleaning without much input from the user',

  author = 'Abhishek Pailwan,Priyanka Singh',                   # Type in your name

  author_email = 'samoyapi@gmail.com',      # Type in your E-Mail

  url = 'https://github.com/samoy-pckg/samoy',   # Provide either the link to your github or to your website

  download_url =

'https://github.com/samoy-pckg/samoy/archive/v_03.zip',    # I explain this later on

  keywords = ['DATA SCIENCE', 'MACHINE LEARNING', 'DATA CLEANING','DATA PREPROCESSING','FEATURE ENGINEERING','DESCRIPTIVE ANALYSIS','PREDICTIVE ANALYSIS','STATISTICAL MODELING','PYTHON','PYSPARK'],   # Keywords that define your package best

  classifiers=[

    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers

    'Topic :: Software Development :: Build Tools',

    'License :: OSI Approved :: MIT License',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support

    'Programming Language :: Python :: 3.4',

    'Programming Language :: Python :: 3.5',

    'Programming Language :: Python :: 3.6',

  ],

)

 

